package com.ynet.life.base;

import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafTools;
import java.io.OutputStream;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

/* loaded from: com_ynet_life_base.jar:com/ynet/life/base/LifeDBLobUtil.class */
public class LifeDBLobUtil {
    public static final int BLOB_INSERT = 1;
    public static final int BLOB_UPDATE = 2;
    public static final int BLOB_SELECT = 3;

    public static void insertBlob(Connection connection, String tableName, String pryKey, String pryKeyValue, String[] commField, String[] commValue, String[] blobField, String[] blobValue) throws TranFailException {
        String sqlInsert = getPrepareSQL(1, tableName, pryKey, pryKeyValue, commField, commValue, blobField, blobValue);
        String sqlSelect = getPrepareSQL(3, tableName, pryKey, pryKeyValue, commField, commValue, blobField, blobValue);
        Trace.logDebug(Trace.COMPONENT_JDBC, "执行Blob--->".concat(String.valueOf(sqlInsert)));
        Trace.logDebug(Trace.COMPONENT_JDBC, "执行Blob--->".concat(String.valueOf(sqlSelect)));
        writeBlob(connection, sqlInsert, sqlSelect, pryKeyValue, commValue, blobField, blobValue);
    }

    public static void updateBlob(Connection connection, String tableName, String pryKey, String pryKeyValue, String[] commField, String[] commValue, String[] blobField, String[] blobValue) throws TranFailException {
        String sqlUpdate = getPrepareSQL(2, tableName, pryKey, pryKeyValue, commField, commValue, blobField, blobValue);
        String sqlSelect = getPrepareSQL(3, tableName, pryKey, pryKeyValue, commField, commValue, blobField, blobValue);
        Trace.logDebug(Trace.COMPONENT_JDBC, "执行Blob--->".concat(String.valueOf(sqlUpdate)));
        Trace.logDebug(Trace.COMPONENT_JDBC, "执行Blob--->".concat(String.valueOf(sqlSelect)));
        writeBlob(connection, sqlUpdate, sqlSelect, pryKeyValue, commValue, blobField, blobValue);
    }

    public static void writeBlob(Connection connection, String sqlUpdate, String sqlSelect, String pryKeyValue, String[] commValue, String[] blobField, String[] blobValue) throws TranFailException {
        try {
            PreparedStatement pstmt = getPrepareStatement(connection, sqlUpdate, pryKeyValue, commValue);
            pstmt.executeUpdate();
            pstmt.close();
            ResultSet rset = getPrepareStatement(connection, sqlSelect, pryKeyValue, commValue).executeQuery();
            if (rset.next()) {
                for (int i = 0; i < blobField.length; i++) {
                    OutputStream out = rset.getBlob(blobField[i]).setBinaryStream(1L);
                    out.write(blobValue[i].getBytes("UTF-8"));
                    out.close();
                }
            }
        } catch (Exception ex) {
            Trace.logError(Trace.COMPONENT_ACTION, "更新Blob字段失败", ex);
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "更新Blob字段失败", ex, false);
        }
    }

    public static String getPrepareSQL(int sqlType, String tableName, String pryKey, String pryKeyValue, String[] commField, String[] commValue, String[] blobField, String[] blobValue) {
        StringBuffer sqlBuffer = new StringBuffer();
        if (sqlType == 1) {
            sqlBuffer.append("INSERT INTO ");
            sqlBuffer.append(tableName);
            sqlBuffer.append("(");
            for (String str : commField) {
                sqlBuffer.append(str).append(',');
            }
            for (String str2 : blobField) {
                sqlBuffer.append(str2).append(',');
            }
            LoafTools.removeLastComma(sqlBuffer);
            sqlBuffer.append(") VALUES (");
            for (int i = 0; i < commValue.length; i++) {
                sqlBuffer.append("?,");
            }
            for (int i2 = 0; i2 < blobValue.length; i2++) {
                sqlBuffer.append("GENETY_BLOB(),");
            }
            LoafTools.removeLastComma(sqlBuffer);
            sqlBuffer.append(")");
        } else if (sqlType == 2) {
            sqlBuffer.append("UPDATE ");
            sqlBuffer.append(tableName);
            sqlBuffer.append(" SET ");
            for (String str3 : commField) {
                sqlBuffer.append(str3).append("=?,");
            }
            for (String str4 : blobField) {
                sqlBuffer.append(str4).append("=GENETY_BLOB(),");
            }
            LoafTools.removeLastComma(sqlBuffer);
            sqlBuffer.append(" WHERE ");
            sqlBuffer.append(pryKey).append("=?");
        } else {
            sqlBuffer.append("SELECT ");
            for (String str5 : blobField) {
                sqlBuffer.append(str5).append(" ,");
            }
            LoafTools.removeLastComma(sqlBuffer);
            sqlBuffer.append(" FROM ");
            sqlBuffer.append(tableName);
            sqlBuffer.append(" WHERE ");
            sqlBuffer.append(pryKey).append("=?");
            sqlBuffer.append(" FOR UPDATE");
        }
        return sqlBuffer.toString();
    }

    public static PreparedStatement getPrepareStatement(Connection connection, String sql, String pryKeyValue, String[] commValue) throws SQLException {
        PreparedStatement pstmt = connection.prepareStatement(sql);
        if (sql.startsWith("INSERT INTO")) {
            for (int i = 0; i < commValue.length; i++) {
                pstmt.setString(i + 1, commValue[i]);
            }
        } else if (sql.startsWith("UPDATE")) {
            for (int i2 = 0; i2 < commValue.length; i2++) {
                pstmt.setString(i2 + 1, commValue[i2]);
            }
            pstmt.setString(commValue.length + 1, pryKeyValue);
        } else {
            pstmt.setString(1, pryKeyValue);
        }
        return pstmt;
    }
}
